..
    This file is part of Invenio.
    Copyright (C) 2015, 2016 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

.. _module_oauthclient:

Invenio-OAuthClient
====================

Contents
========

.. toctree::
   :maxdepth: 2

.. _module_oauthclient_conf:

.. include:: ../README.rst

User's Guide
============

This part of the documentation will show you how to get started in using
Invenio-OAuthClient.

.. toctree::
  :maxdepth: 2

  installation
  howtouse
  contributing

API Reference
=============

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
  :maxdepth: 2

  contrib
  api

Additional Notes
================

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   contributing
   changes
   license
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
